package SAE.ApiREST.WebService.controller;

import SAE.ApiREST.WebService.exception.TeacherAdvice;
import SAE.ApiREST.WebService.exception.TeacherException;
import SAE.ApiREST.WebService.model.Teacher;
import SAE.ApiREST.WebService.service.ITeacherService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.print.attribute.standard.Media;
import java.awt.*;
import java.util.ArrayList;
import java.util.List;

//Todo() Response = Type de retour pour toutes les méthodes qui ont void
@Controller
@RequestMapping("/ProfWebService")
public class TeacherController {
    @Autowired
    private ITeacherService iTeacherServ;


    public TeacherController(ITeacherService iserv) {
        this.iTeacherServ = iserv;
    }

    @GetMapping(value = "/all", produces = MediaType.APPLICATION_JSON_VALUE)
    @ResponseStatus(HttpStatus.OK)
    public @ResponseBody List<Teacher> getAllTeacher(){
        return iTeacherServ.getAllTeacher();
    }
    @PostMapping(value = "addTeacher",produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    @ResponseStatus(HttpStatus.CREATED)
    public @ResponseBody Teacher createTeacher( @RequestBody Teacher teach){
        return teach;
    }
    @GetMapping(value = "/getid/{id}")
    public @ResponseBody Teacher getTeachById(@PathVariable("id") Integer id){
        Teacher tt = iTeacherServ.getTeacherById(id);
        if( tt == null ){
            throw new TeacherException("No teacher found for this id !");
        }
        return tt;
    }
    @GetMapping(value = "/getusername/{username}")
    public @ResponseBody Teacher getTeachByUsername(@PathVariable("username") String username) {
        Teacher tt = iTeacherServ.getTeacherByUsername(username);
        if (tt == null) {
            throw new TeacherException("No teacher found for this username");
        }
        return tt;
    }
    @GetMapping( value = "/getmail/{mail}" )
    public @ResponseBody Teacher getTeachByMail(@PathVariable("mail") String mail) {
        Teacher tt = iTeacherServ.getTeacherByMail(mail);
        if( tt == null ) {
            throw new TeacherException("No teacher found for this mail");
        }
        return  tt;
    }
    @GetMapping( value = "/getdate/{date}" )
    public @ResponseBody Teacher getTeachByDate(@PathVariable("date") String date) {
        Teacher tt = iTeacherServ.getTeacherByMail(date);
        if( tt == null ) {
            throw new TeacherException("No teacher found for this mail");
        }
        return  tt;
    }
    @PutMapping( value = "/modify/{username}" )
    public @ResponseBody Teacher modifyTeachUsername(@PathVariable("username") String username, Teacher tt){
        if( username == "" ){
            throw new TeacherException("Username provided for modification is empty");
        }
        iTeacherServ.modifyUsername(tt,username);
        return tt;
    }
    @DeleteMapping( value = "delete")
    public @ResponseBody List<Teacher> deleteTeacher(Integer id){
        return iTeacherServ.deleteTeacher(id);
    }
}
